@@ -3,7 +3,7 @@ package Sah::Schema::date::dow_name::id;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [cistr => {
     summary => 'Day-of-week name (abbreviated or full, in Indonesian)',
@@ -45,20 +45,70 @@ Sah::Schema::date::dow_name::id - Day-of-week name (abbreviated or full, in Indo
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::date::dow_name::id (from Perl distribution Sah-Schemas-Date-ID), released on 2021-08-04.
+This document describes version 0.007 of Sah::Schema::date::dow_name::id (from Perl distribution Sah-Schemas-Date-ID), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # INVALID (Empty string)
+
+ "mg"  # valid
+
+ "min"  # valid
+
+ "minggu"  # valid
+
+ "sun"  # INVALID (English)
+
+ 1  # INVALID (Not a name)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
  my $validator = gen_validator("date::dow_name::id*");
  say $validator->($data) ? "valid" : "INVALID!";
 
- # Data::Sah can also create validator that returns nice error message string
- # and/or coerced value. Data::Sah can even create validator that targets other
- # language, like JavaScript. All from the same schema. See its documentation
- # for more details.
+The above schema returns a boolean value (true if data is valid, false if
+otherwise). To return an error message string instead (empty string if data is
+valid, a non-empty error message otherwise):
+
+ my $validator = gen_validator("date::dow_name::id", {return_type=>'str_errmsg'});
+ my $errmsg = $validator->($data);
+ 
+ # a sample valid data
+ $data = "min";
+ my $errmsg = $validator->($data); # => ""
+ 
+ # a sample invalid data
+ $data = "sun";
+ my $errmsg = $validator->($data); # => "Must be one of [\"mg\",\"sn\",\"sl\",\"rb\",\"km\",\"jm\",\"sb\",\"min\",\"sen\",\"sel\",\"rab\",\"kam\",\"jum\",\"sab\",\"minggu\",\"senin\",\"selasa\",\"rabu\",\"kamis\",\"jumat\",\"sabtu\"]"
+
+Often a schema has coercion rule or default value, so after validation the
+validated value is different. To return the validated (set-as-default, coerced,
+prefiltered) value:
+
+ my $validator = gen_validator("date::dow_name::id", {return_type=>'str_errmsg+val'});
+ my $res = $validator->($data); # [$errmsg, $validated_val]
+ 
+ # a sample valid data
+ $data = "min";
+ my $res = $validator->($data); # => ["","min"]
+ 
+ # a sample invalid data
+ $data = "sun";
+ my $res = $validator->($data); # => ["Must be one of [\"mg\",\"sn\",\"sl\",\"rb\",\"km\",\"jm\",\"sb\",\"min\",\"sen\",\"sel\",\"rab\",\"kam\",\"jum\",\"sab\",\"minggu\",\"senin\",\"selasa\",\"rabu\",\"kamis\",\"jumat\",\"sabtu\"]","sun"]
+
+Data::Sah can also create validator that returns a hash of detaild error
+message. Data::Sah can even create validator that targets other language, like
+JavaScript, from the same schema. Other things Data::Sah can do: show source
+code for validator, generate a validator code with debug comments and/or log
+statements, generate human text from schema. See its documentation for more
+details.
+
+=head2 Using with Params::Sah
 
 To validate function parameters against this schema (requires L<Params::Sah>):
 
@@ -71,8 +121,10 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
  package
@@ -110,20 +162,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # INVALID (Empty string)
-
- "mg"  # valid
-
- "min"  # valid
-
- "minggu"  # valid
-
- "sun"  # INVALID (English)
-
- 1  # INVALID (Not a name)
-
 =head1 DESCRIPTION
 
 See also related schemas for other locales, e.g.
